#ifndef _COMPETINO_H_
#define _COMPETINO_H_

#include <stdio.h>
#include "macros.h"

/* the description of the EEPROM items */
typedef struct {
    const int address;
    const char* name;
    const char* text;
    const enum { CSTRING, SIGNED, UNSIGNED } type;
    const size_t size;
    const char* range;
    const char* remarks;
} description_t;


typedef struct {
    const description_t *description;
    union {
	char *cstring;
	int  number;
    } value;
    int dirty;
} option_t;

enum options {
    #include "competino.h.eeprom"
    _LAST_ = -1,
};


/* read the complete EEPROM (the settings) and return a pointer to a
 * malloc()ed list of items, each item is a struct as above, the 
 * end of the list is marked by a NULL description_t*
 */
option_t* read_eeprom(FILE *port);

option_t read_option_byname(FILE *port, const char *name);
option_t read_option_byaddr(FILE *port, enum options addr);
void write_option_byname(FILE *port, const char *name, const char *value);
void destroy_option(option_t);

const char* option_value(option_t o);
void print_option(FILE*, option_t o);

#endif
