#include <stdio.h>
#include <assert.h>
#include <unistd.h>
#include <string.h>

#include "main.h"
#include "nmea.h"
#include "com.h"

#include "competino.h"

#ifndef DEFAULT_PORT
#define DEFAULT_PORT "/dev/ttyUSB1"
#endif

int debug;

int main(int argc, char **argv)
{
    const char *portname = DEFAULT_PORT;
    FILE *port;
    int opt;

    ME = argv[0];

    while ((opt = getopt(argc, argv, "dp")) != -1) {
        switch (opt) {
            case 'p': 
                portname = argv[optind++];
                break;
            case 'd':   
                debug = 1;
                break;
               default:    fprintf(stderr, "Usage: %s [-d] [-p port] [commands…]\n", argv[0]);
                           exit(1);
        }
    }

    port = setup_port(portname);

    /* no command, ask for serial */
    if (argv[optind] == NULL) {
        puts(talk(port, "SNP"));
        exit(EXIT_SUCCESS);
    }

    /* raw - send the raw commands */
    if (strcmp(argv[optind], "raw") == 0) {
        for (optind++; argv[optind]; optind++) {
            const char* answer = talk(port, argv[optind]);
            int n = printf("%s", answer);
            if (n && *(answer + n - 1) != '\n') puts("");
        }
        exit(EXIT_SUCCESS);
    }

    /* get - get all or single items */
    if (strcmp(argv[optind], "get") == 0) {
        if (!argv[optind + 1]) {
            option_t *options, *i;
            for (i = options = read_eeprom(port); i->description; ++i) {
                print_option(stdout, *i);
                destroy_option(*i);
            }
            free(options);
        } 
        else for (optind++; argv[optind]; optind++) {
            option_t o = read_option_byname(port, argv[optind]);
            print_option(stdout, o);
            destroy_option(o);
        }
        exit(EXIT_SUCCESS);
    }

    /* set - set single items */
    if (strcmp(argv[optind], "set") == 0) {
        for (optind++; argv[optind]; optind++) {
            char *p = strchr(argv[optind], '=');
            if (!p) DIE("bad command syntax");
            *p++ = '\0';
            if (!*p) DIE("missing value");
            write_option_byname(port, argv[optind], p);
        }
        exit(EXIT_SUCCESS);
    }

    fprintf(stderr, "%s: bad usage\n", argv[0]);
    exit(EXIT_FAILURE);

}

/* vim:ts=4 sw=4 et:
 */
